import setuptools
 
setuptools.setup(
    name="pranks",
    version="1.0.0",
    author="TabsOrSpace",
    description="Pranks",
    url="",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Operating System :: OS Independent",
    ],
)